.. SDyPy project template documentation master file, created by
   sphinx-quickstart on Wed Jul 10 08:16:05 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to the SDyPy-view project's documentation!
===============================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   getting_started
   code



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
